pub struct GameObject {
pub id: GameObjectId,
pub name: String,
/* private fields */
}Expand description
The GameObject. The main entity within the game world. Contains a set of components that run the actual gameplay logic.
Fields
id: GameObjectIdThe unique identifier for this GameObject
name: StringThe name of this GameObject
Implementations
Sourceimpl GameObject
impl GameObject
Sourcepub fn new(name: Option<impl Into<String>>) -> Self
pub fn new(name: Option<impl Into<String>>) -> Self
Creates a new GameObject that is not yet loaded into the world.
Sourcepub fn add_component(&mut self, component: impl Component)
pub fn add_component(&mut self, component: impl Component)
Adds a new component to this GameObject