replace

Function replace 

pub fn replace<T: Any + Send + Sync>(value: T) -> Result<(), T>
Replaces the global of type T with a new value. This does not modify the global value for any other threads that currently have a reference to the global, but only marks it as deleted. If the global does not exist, returns Err