MessageCompatible

Trait MessageCompatible 

pub trait MessageCompatible:
    Any
    + Send
    + Sync
    + Debug {
    // Required method
    fn as_any(&self) -> &dyn Any;
}
A marker trait signalling that a type is safe to send as a cross-gameobject message. Implemented automatically if the required traits Any, Send, Sync and Debug are also implemented.

Required Methods

fn as_any(&self) -> &dyn Any

Casts the message to an Any reference, for internal conversions.

Implementors

Source

impl<T> MessageCompatible for T
where T: Any + Send + Sync + Debug,