pub struct Transform { /* private fields */ }Expand description
The transform component. Contains all information about the place of an entity in 3D space.
Implementations
Sourceimpl Transform
impl Transform
Sourcepub fn with_pos(pos: Vec3) -> Self
pub fn with_pos(pos: Vec3) -> Self
Creates a new transform with the given position, but with identity scale and rotation
Sourcepub fn with_rot(rot: Quat) -> Self
pub fn with_rot(rot: Quat) -> Self
Creates a new transform with the given rotation, but with identity position and scale
Sourcepub fn with_scale(scale: Vec3) -> Self
pub fn with_scale(scale: Vec3) -> Self
Creates a new transform with the given scale, but with identity position and rotation
Sourcepub fn with_pos_rot(pos: Vec3, rot: Quat) -> Self
pub fn with_pos_rot(pos: Vec3, rot: Quat) -> Self
Creates a new transform with the given position and rotation, but with identity scale
Sourcepub fn with_pos_rot_scale(pos: Vec3, rot: Quat, scale: Vec3) -> Self
pub fn with_pos_rot_scale(pos: Vec3, rot: Quat, scale: Vec3) -> Self
Creates a new transform with the given local position, rotation and scale
Sourcepub fn set_world_pos(&mut self, pos: Vec3)
pub fn set_world_pos(&mut self, pos: Vec3)
Sets the world-space position of this transform
Sourcepub fn set_local_pos(&mut self, pos: Vec3)
pub fn set_local_pos(&mut self, pos: Vec3)
Sets the local-space position of this transform
Sourcepub fn set_world_rot(&mut self, rot: Quat)
pub fn set_world_rot(&mut self, rot: Quat)
Sets the world-space rotation of this transform
Sourcepub fn set_local_rot(&mut self, rot: Quat)
pub fn set_local_rot(&mut self, rot: Quat)
Sets the local-space rotation of this transform
Sourcepub fn local_scale(&self) -> Vec3
pub fn local_scale(&self) -> Vec3
Gets the local-space scale of this transform
Sourcepub fn lossy_scale(&self) -> Vec3
pub fn lossy_scale(&self) -> Vec3
Gets the lossy world-space scale of this transform. Note: The world-space scale is lossy due to the math that is involved. It will be inaccurate
Sourcepub fn local_to_world(&self) -> Mat4
pub fn local_to_world(&self) -> Mat4
Gets the local-to-world matrix of this transform
Sourcepub fn world_to_local(&self) -> Mat4
pub fn world_to_local(&self) -> Mat4
Gets the world-to-local matrix of this transform