pub trait MessageCompatible: Any + Send + Sync + Debug { // Required method fn as_any(&self) -> &dyn Any; }
A marker trait signalling that a type is safe to send as a cross-gameobject message. Implemented automatically if the required traits Any, Send, Sync and Debug are also implemented.
Casts the message to an Any reference, for internal conversions.